/**
 * @file TMDataManager.m
 *
 * @brief Data Manager Class.
 *
 * @author
 *  Copyright (C) SEIKO EPSON CORPORATION 2009.
 *
 *  Driver for EPSON Thermal Printers Series.
 */

#import		"TMDataManager.h"

@interface TMDataManager (no_warnings)

- (void)setupPSUList;
@end

@implementation TMDataManager
#pragma mark # Function Related #

- (id)initUIManager
{
	self = [super init];

	if( self != nil )
	{
		
		iSelectPrinterIndex = -1;
		iIsiEmptyData = NO;

		iPPDAccess = [[TMPPDAccess alloc] initWithPPDAccess];
		
		iPrinterList = [[NSMutableArray alloc] initWithCapacity:0];
		[iPrinterList removeAllObjects];
		iQueList = [[NSMutableArray alloc] initWithCapacity:0];
		[iQueList removeAllObjects];
		[self setupPSUList];			
		
		iDataDict = [[NSMutableDictionary alloc] initWithCapacity:0];
		[iDataDict removeAllObjects];
		
	}			
	return (self);
}

-(NSString*)getPopupButtonDefaultData:(NSString*)keyword
{

	NSString		*queName = nil;
	NSString		*choice = nil;
	
	if( iSelectPrinterIndex != -1 && [iPrinterList count] > 0 && [iQueList count] > 0)
	{
		queName = [iQueList objectAtIndex:iSelectPrinterIndex];
	}

	if( queName != nil ){
		choice = [iPPDAccess getPPDDefaultChoice:[TMUtilities strNSToC:queName encoding:NSMacOSRomanStringEncoding] key:keyword];
	}
	
	return choice;
}


- (void)setPopupButtonData:(NSString*)choice keyword:(NSString*)keyword
{
	[iDataDict setObject:choice forKey:keyword];
}

- (void)setIsEmptyData:(SInt16)iState
{
	if( iState > 0 ){
		iIsiEmptyData = YES;
	} else {
		iIsiEmptyData = NO;
	}
}

- (BOOL)getIsEmptyData
{
	return iIsiEmptyData;
}

- (void)setSelectPrinterNameIndex:(SInt16)index
{
	iSelectPrinterIndex = index;
	
}

- (NSSize)getPaperSize:(NSString*)iData
{
	if( [iData isEqualToString:@"RP80x297"] == YES ){
		return NSMakeSize((CGFloat)204.0, (CGFloat)841.8);
	} else if( [iData isEqualToString:@"RP58x297"] == YES ){
		return NSMakeSize((CGFloat)141.7, (CGFloat)841.8);
	} else {
		return NSMakeSize(0, 0);
	}
}

- (NSInteger)getSelectPrinterNameIndex
{
	return iSelectPrinterIndex;
	
}

- (NSString*)getSelectQueName
{
	if( iSelectPrinterIndex != -1 && [iPrinterList count] <= 0 || [iQueList count] <= 0 )
		return nil;
	
	return [iQueList objectAtIndex:iSelectPrinterIndex];
	
	
}

- (NSString*)getSelectPrinterName
{
	if( iSelectPrinterIndex != -1 && [iPrinterList count] <= 0 || [iQueList count] <= 0 )
		return nil;
	
	return [iPrinterList objectAtIndex:iSelectPrinterIndex];
	
	
}

- (NSString*)getPrinterNameFromIndex:(SInt16)index
{
	if( [iPrinterList count] <= index )
		return nil;
	
	return [iPrinterList objectAtIndex:index];
	
}

- (NSString*)getDataFromKeyword:(NSString*)keyword
{
	
	return [iDataDict objectForKey:keyword];
	
}


#pragma mark # Private Related #

- (void)setupPSUList
{
	BOOL			flg = NO;
	OSStatus		err = noErr;
	CFStringRef		queName = nil;
	CFStringRef		printerName = nil;
	CFArrayRef		printerList = nil;
	PMPrinter		pmPrinter = nil;
	PMServer		server = kPMServerLocal;
	SInt16			i = 0;

	err = PMServerCreatePrinterList(server, &printerList);
	if (err == noErr) {
		if( CFArrayGetCount(printerList) != 0 ) flg = YES;
	}
	
	if(flg)
	{
		for( i = 0 ; i < CFArrayGetCount(printerList) ; i++ ) 
		{
			if((pmPrinter = (PMPrinter)CFArrayGetValueAtIndex(printerList, i)) != nil) 
			{
				if((queName = PMPrinterGetID(pmPrinter)) != nil) 
				{
					printerName = PMPrinterGetName(pmPrinter);
					if( PMPrinterIsFavorite(pmPrinter) )
					{

						char			cname[256];
						CFStringGetCString(queName, cname, sizeof(cname), CFStringGetSystemEncoding());
						
						if( [iPPDAccess isMyPrinter:cname] == YES ){
							[iPrinterList addObject:[NSString stringWithString:(NSString*)printerName]];
							[iQueList addObject:[NSString stringWithString:(NSString*)queName]];
						}
					}
				}
			}
		}
		if( iPrinterList != nil && [iPrinterList count] > 0 ) {
			[self setSelectPrinterNameIndex:0];
		}
	}
}


#pragma mark # Override Related #

- (void)dealloc
{
	
	myRelease(iDataDict);
	myRelease(iPrinterList);
	myRelease(iPPDAccess);
	
	[super dealloc];
	
}



@end
