/**
 * @file TMPPDAccess.m
 *
 * @brief PPD Access Class.
 *
 * @author
 *  Copyright (C) SEIKO EPSON CORPORATION 2009.
 *
 *  Driver for EPSON Thermal Printers Series.
 */

#import "TMPPDAccess.h"
#include "TMUtilities.h"
#include <cups/cups.h>
#include <cups/ppd.h>

@implementation TMPPDAccess

#pragma mark -
#pragma mark # Override Related #

- (void)dealloc
{
	
	[super dealloc];
}


#pragma mark -
#pragma mark # Function Related #

- (id)initWithPPDAccess
{
	self = [super init];
	if (self != nil)
	{
	}
	
	return (self);
}

- (BOOL)isMyPrinter:(const char*)iPrinterName
{
	const char		*ppdFile;
	ppd_file_t		*ppdInfo;
	char			name[256];
	ppd_attr_t		*attr = nil;
	
	ppdFile = cupsGetPPD(iPrinterName);
	if ( ppdFile == nil )
		return NO;
	
	ppdInfo = ppdOpenFile(ppdFile);
	if ( ppdInfo == nil ) {
		unlink( ppdFile );
		return NO;
	}
	
	attr = ppdFindAttr(ppdInfo, PPDKEY, nil);
	if (attr != nil) {
		strcpy(name, attr->value);
	}
	
	ppdClose( ppdInfo );
	unlink( ppdFile );
	
	if( strncmp( name, PPDDATA, strlen((const char *)PPDDATA )) == 0 ) {
		return YES;
	}
	
	return NO;
}


- (NSString*)getPPDDefaultChoice:(const char*)iPrinterName key:(NSString*)keyword
{
	NSString		*itemChoice = nil;
	const char		*ppdFile;
	ppd_file_t		*ppdInfo = nil;
	ppd_option_t	*option = nil;
	
	ppdFile = cupsGetPPD(iPrinterName);
	if ( ppdFile == nil )
		return nil;
	
	ppdInfo = ppdOpenFile(ppdFile);
	if ( ppdInfo == nil ) {
		unlink( ppdFile );
		return nil;
	}
		
	option = ppdFindOption(ppdInfo, [TMUtilities strNSToC:keyword encoding:NSASCIIStringEncoding]);
	if(option != nil){
		itemChoice = [NSString stringWithCString:option->defchoice encoding:NSASCIIStringEncoding];
	}
	
	ppdClose( ppdInfo );
	unlink( ppdFile );
	
	return (itemChoice);
}



@end
