/**
 * @file TMTextView.m
 *
 * @brief Sample Data View Class.
 *
 * @author
 *  Copyright (C) SEIKO EPSON CORPORATION 2009.
 *
 *  Driver for EPSON Thermal Printers Series.
 */


#import "TMTextView.h"

@interface TMTextView (no_warnings)

- (void)drawText;
- (void)drawHeader;
- (void)drawBody;
- (void)drawFooter;

@end

@implementation TMTextView

#pragma mark # Override Related #
- (void)dealloc
{	
	[super dealloc];
}

- (void)drawRect:(NSRect)rect {
	
	
	iViewRect = [self bounds];
	if( iPaperSize.width < iViewRect.size.width ){
		iViewRect.size.width = iPaperSize.width;
	}
	
	[[NSColor colorWithCalibratedRed:1. green:1. blue:1. alpha:1.] set];
	NSRectFill(iViewRect);

	[self drawHeader];
	
	[self drawBody];
	
	[self drawFooter];
	
}

#pragma mark # Function Functions #

- (id)initWithFrame:(NSRect)frame {
    self = [super initWithFrame:frame];
    if (self) {
		
    }
    return self;
}

- (void) setPaperViewSize:(NSSize)paperSize
{
	iPaperSize = paperSize;
}

#pragma mark # Private Functions #
- (void)drawHeader
{	
	// logo
	NSImage *image = [NSImage imageNamed:@"logo.png"];
	NSRect rect = NSMakeRect(0,0, image.size.width, image.size.height);
	CGFloat ratio = (iViewRect.size.width - 20) / image.size.width;
	iYPos = iViewRect.size.height - 10. - image.size.height * ratio;
	NSRect imgRect = NSMakeRect(10, iYPos, image.size.width * ratio, image.size.height * ratio);
	[image drawInRect:imgRect fromRect:rect operation:NSCompositeCopy fraction:1.0];
	
	// separater
	iYPos = iYPos - 5.;
	NSBezierPath *linePath = [NSBezierPath bezierPath];
	[linePath moveToPoint:NSMakePoint(iViewRect.origin.x + 10., iYPos)];
	[linePath lineToPoint:NSMakePoint(NSMaxX(iViewRect) - 10, iYPos)];
	[linePath setLineWidth:2.];
	[[NSColor colorWithCalibratedRed:0. green:0. blue:0. alpha:1.] set];
	[linePath stroke];
	
	// address
	iYPos = iYPos - 5.;
	NSMutableAttributedString *str = [[NSMutableAttributedString alloc] initWithString:@"2070 Kotobuki Koaka,\rMatsumoto, \rNagano 399-8702\r Phone:555-111-1111"];
	NSFont* f1 = [NSFont systemFontOfSize:11.0];
	[str setAttributes:[NSDictionary dictionaryWithObject:f1 forKey:NSFontAttributeName] range:NSMakeRange(0,[str length])];
	[str setAlignment:NSCenterTextAlignment range:NSMakeRange(0,[str length])];
	iYPos = iYPos - 18.*4.;
	rect = NSMakeRect(10, iYPos, NSMaxX(iViewRect) - 10 - 10, 18.*4);
	[str drawInRect:rect];
	[str release];
	
	// date
	NSMutableAttributedString *dateStr = [[NSMutableAttributedString alloc] initWithString:@"02/03/2010"];
	NSFont* f2 = [NSFont systemFontOfSize:12];
	[dateStr setAttributes:[NSDictionary dictionaryWithObject:f2 forKey:NSFontAttributeName] range:NSMakeRange(0,[dateStr length])];
	[dateStr setAlignment:NSLeftTextAlignment range:NSMakeRange(0,[dateStr length])];
	iYPos = iYPos - 14.;
	rect = NSMakeRect(10, iYPos, NSMaxX(iViewRect) - 10 - 10, 18.);
	[dateStr drawInRect:rect];
	[dateStr release];
	
	// time
	NSMutableAttributedString *timeStr = [[NSMutableAttributedString alloc] initWithString:@"#0123    10:25"];
	[timeStr setAttributes:[NSDictionary dictionaryWithObject:f1 forKey:NSFontAttributeName] range:NSMakeRange(0,[timeStr length])];
	[timeStr setAlignment:NSLeftTextAlignment range:NSMakeRange(0,[timeStr length])];	
	iYPos = iYPos - 18.;
	rect = NSMakeRect(10, iYPos, NSMaxX(iViewRect) - 10 - 10, 18.);
	[timeStr drawInRect:rect];
	[timeStr release];
	
	// separater
	iYPos = iYPos - 5.;
	[linePath removeAllPoints];
	[linePath moveToPoint:NSMakePoint(iViewRect.origin.x + 10., iYPos)];
	[linePath lineToPoint:NSMakePoint(NSMaxX(iViewRect) - 10, iYPos)];
	[linePath setLineWidth:2.];
	[[NSColor colorWithCalibratedRed:0. green:0. blue:0. alpha:1.] set];
	[linePath stroke];
	
}

- (void)drawBody
{
	// items
	NSArray *items = [NSArray arrayWithObjects:@"MILK", @"BUTTER", nil];
	NSArray *prices = [NSArray arrayWithObjects:@"$3.00", @"$3.99", nil];
	
	iYPos = iYPos - 10.;
	NSInteger i;
	for(i = 0 ; i < [items count] ; i++) {
		NSMutableAttributedString *itemStr = [[NSMutableAttributedString alloc] initWithString:[items objectAtIndex:i]];
		NSFont* f1 = [NSFont systemFontOfSize:12];
		[itemStr setAttributes:[NSDictionary dictionaryWithObject:f1 forKey:NSFontAttributeName] range:NSMakeRange(0,[itemStr length])];
		[itemStr setAlignment:NSLeftTextAlignment range:NSMakeRange(0,[itemStr length])];
		iYPos = iYPos - 14.;
		NSRect rect = NSMakeRect(10, iYPos, NSMaxX(iViewRect) - 10 - 10, 18.);
		[itemStr drawInRect:rect];
		[itemStr release];
		
		NSMutableAttributedString *price = [[NSMutableAttributedString alloc] initWithString:[prices objectAtIndex:i]];
		[price setAttributes:[NSDictionary dictionaryWithObject:f1 forKey:NSFontAttributeName] range:NSMakeRange(0,[price length])];
		[price setAlignment:NSRightTextAlignment range:NSMakeRange(0,[price length])];
		rect = NSMakeRect(10, iYPos, NSMaxX(iViewRect) - 10 - 10, 18.);
		[price drawInRect:rect];
		[price release];
	}
	
	// separater
	iYPos = iYPos - 5.;
	NSBezierPath *linePath = [NSBezierPath bezierPath];
	[linePath moveToPoint:NSMakePoint(iViewRect.origin.x + 10., iYPos)];
	[linePath lineToPoint:NSMakePoint(NSMaxX(iViewRect) - 10, iYPos)];
	[linePath setLineWidth:1.];
	[[NSColor colorWithCalibratedRed:0. green:0. blue:0. alpha:1.] set];
	[linePath stroke];
	
	// subtotal & tax
	NSArray *items2 = [NSArray arrayWithObjects:@"SUBTOTAL", @"TAX", nil];
	NSArray *prices2 = [NSArray arrayWithObjects:@"$6.99", @"$0.34", nil];
	
	iYPos = iYPos - 10.;
	for(i = 0 ; i < [items2 count] ; i++) {
		NSMutableAttributedString *itemStr = [[NSMutableAttributedString alloc] initWithString:[items2 objectAtIndex:i]];
		NSFont* f1 = [NSFont systemFontOfSize:12];
		[itemStr setAttributes:[NSDictionary dictionaryWithObject:f1 forKey:NSFontAttributeName] range:NSMakeRange(0,[itemStr length])];
		[itemStr setAlignment:NSLeftTextAlignment range:NSMakeRange(0,[itemStr length])];
		iYPos = iYPos - 14.;
		NSRect rect = NSMakeRect(10, iYPos, NSMaxX(iViewRect) - 10 - 10, 18.);
		[itemStr drawInRect:rect];
		[itemStr release];
		
		NSMutableAttributedString *price = [[NSMutableAttributedString alloc] initWithString:[prices2 objectAtIndex:i]];
		[price setAttributes:[NSDictionary dictionaryWithObject:f1 forKey:NSFontAttributeName] range:NSMakeRange(0,[price length])];
		[price setAlignment:NSRightTextAlignment range:NSMakeRange(0,[price length])];
		rect = NSMakeRect(10, iYPos, NSMaxX(iViewRect) - 10 - 10, 18.);
		[price drawInRect:rect];
		[price release];
	}
	// separater
	iYPos = iYPos - 5.;
	[linePath removeAllPoints];
	[linePath moveToPoint:NSMakePoint(iViewRect.origin.x + 10., iYPos)];
	[linePath lineToPoint:NSMakePoint(NSMaxX(iViewRect) - 10, iYPos)];
	[linePath setLineWidth:1.];
	[[NSColor colorWithCalibratedRed:0. green:0. blue:0. alpha:1.] set];
	[linePath stroke];
	
	// total
	NSMutableAttributedString *totalStr = [[NSMutableAttributedString alloc] initWithString:@"Total"];
	NSFont* f2 = [NSFont systemFontOfSize:16];
	[totalStr setAttributes:[NSDictionary dictionaryWithObject:f2 forKey:NSFontAttributeName] range:NSMakeRange(0,[totalStr length])];
	[totalStr setAlignment:NSLeftTextAlignment range:NSMakeRange(0,[totalStr length])];
	iYPos = iYPos - 20.;
	NSRect rect = NSMakeRect(10, iYPos, NSMaxX(iViewRect) - 10 - 10, 18.);
	[totalStr drawInRect:rect];
	[totalStr release];
	
	// total
	NSMutableAttributedString *totalStr2 = [[NSMutableAttributedString alloc] initWithString:@"7.33"];
	[totalStr2 setAttributes:[NSDictionary dictionaryWithObject:f2 forKey:NSFontAttributeName] range:NSMakeRange(0,[totalStr2 length])];
	[totalStr2 setAlignment:NSRightTextAlignment range:NSMakeRange(0,[totalStr2 length])];
	rect = NSMakeRect(10, iYPos, NSMaxX(iViewRect) - 10 - 10, 18.);
	[totalStr2 drawInRect:rect];
	[totalStr2 release];
	
}

- (void)drawFooter
{
	// separater
	iYPos = iYPos - 10.;
	NSBezierPath *linePath = [NSBezierPath bezierPath];
	[linePath moveToPoint:NSMakePoint(iViewRect.origin.x + 10., iYPos)];
	[linePath lineToPoint:NSMakePoint(NSMaxX(iViewRect) - 10, iYPos)];
	[linePath setLineWidth:2.];
	[[NSColor colorWithCalibratedRed:0. green:0. blue:0. alpha:1.] set];
	[linePath stroke];
	
	// footer
	iYPos = iYPos - 15.;
	NSMutableAttributedString *str = [[NSMutableAttributedString alloc] initWithString:@"For your comments: \r555-111-2222"];
	NSFont* f1 = [NSFont systemFontOfSize:11];
	[str setAttributes:[NSDictionary dictionaryWithObject:f1 forKey:NSFontAttributeName] range:NSMakeRange(0,[str length])];
	[str setAlignment:NSLeftTextAlignment range:NSMakeRange(0,[str length])];
	iYPos = iYPos - 18.*4.;
	NSRect rect = NSMakeRect(10, iYPos, NSMaxX(iViewRect) - 10 - 10, 18.*4);
	[str drawInRect:rect];
	[str release];
	
}

@end
