/**
 * @file TMUtilities.m
 *
 * @brief Utilities Class.
 *
 * @author
 *  Copyright (C) SEIKO EPSON CORPORATION 2009.
 *
 *  Driver for EPSON Thermal Printers Series.
 */

#include "TMUtilities.h"

short getOSVersion(SInt32 *OSVersion)
{
	SInt16		status = -1;
	SInt32		theOSVer = 0;
	
	status = Gestalt(gestaltSystemVersion, &theOSVer);
	if (status == noErr && theOSVer != 0)
	{
		if (OSVersion != NULL)
		{
			*OSVersion = theOSVer;
		}
		
		status = (theOSVer & MACOSRELEASE);
	}
	else if (theOSVer == 0)
	{
		status = -1;
	}
	
	return (status);
}

void myRelease(id i_obj)
{
	if (i_obj != nil)
	{
		[i_obj release];
		i_obj = nil;
	}
}

OSStatus
getPluginVersion(
				 CFStringRef			inFrameworkName,
				 SInt32				*outMVersion,
				 SInt32				*outRVersion)
{
	OSStatus			err = noErr;
	CFMutableStringRef  plistStr;
	CFURLRef			plistUrl;
	CFDataRef 			dataRef = NULL;
	SInt32				errorCode = noErr;
	CFDictionaryRef		thePropertyList = NULL;
    CFStringRef			keyName = NULL;
    CFStringRef 		value = NULL;
    Boolean				found;
	Boolean				ret;
	char				version[64];
	char				workBuf[32];
	char				*work_p;
	
	
	if (outMVersion == NULL)
	{
		err = paramErr;
		goto done;
	}
	
	zeroMemory(version, sizeof(version));
	
	plistStr = CFStringCreateMutableCopy(
										 CFAllocatorGetDefault(), 
										 0,
										 CFSTR("file://localhost" ));
	if (plistStr == NULL)
	{
		err = -1;
		goto done;
	}
	
	CFStringAppend( plistStr, inFrameworkName );
	
	CFStringAppend( plistStr, CFSTR( "/Contents/Info.plist" ) );
	
	plistUrl = CFURLCreateWithString(CFAllocatorGetDefault(), plistStr, NULL);
	CFRelease( plistStr );
	if (plistUrl == NULL)
	{
		err = -2;
		goto done;
	}
		
	ret = CFURLCreateDataAndPropertiesFromResource(
												   CFAllocatorGetDefault(),
												   plistUrl,
												   &dataRef,
												   NULL,
												   NULL,
												   &errorCode );
	CFRelease( plistUrl );
		
    if (dataRef != NULL &&
		errorCode == 0)
	{
		thePropertyList = (CFDictionaryRef)CFPropertyListCreateFromXMLData(
																		   CFAllocatorGetDefault(),
																		   dataRef,
																		   kCFPropertyListImmutable,
																		   NULL );
		CFRelease( dataRef );
    }
	
    if(thePropertyList == NULL)
	{
		err = -3;
    	goto done;
    }
	
	keyName = CFStringCreateCopy( CFAllocatorGetDefault(), CFSTR("CFBundleVersion") );
	if (keyName == NULL)
	{
		err = -4;
		goto done;
	}
	
	found = CFDictionaryGetValueIfPresent(thePropertyList, keyName, (const void**) &value);
	CFRelease( keyName );
	if (found == TRUE && 
		value != NULL)
	{
		if (CFStringGetCString(value, version, sizeof(version), kCFStringEncodingMacRoman) == FALSE)
		{
			err = -5;
		}
    }
	
done:
	if(thePropertyList)
	{
		CFRelease( thePropertyList );
	}
	if (err == noErr)
	{
		work_p = strchr(version, '.');
		if (work_p != NULL)
		{
			*work_p++ = MYNULL;
			strcpy(workBuf, version);
			
			*outMVersion = atol(workBuf);
			
			strcpy(workBuf, work_p);
			if (outRVersion != NULL)
			{
				*outRVersion = atol(workBuf);
			}
		}
		else
		{
			err = -6;
		}
	}
	
	return (err);
}

void
zeroMemory(void *p, SInt32 size)
{
	SInt32	i;
	char	*cp = (char *)p;
	
	for(i = 0; i < size; i++) {
		cp[i] = 0;
	}
}


@implementation TMUtilities

+ (NSString*)strToEncoding:(NSString*)i_str encoding:(NSStringEncoding)i_encoding
{
	NSUInteger				len = 0;
	NSData					*work;
	NSStringEncoding		encoding;
	
	work = [i_str dataUsingEncoding:encoding allowLossyConversion:NO];
	if (work != nil)
	{
		len = [work length];
	}
	
	return ([[[NSString alloc] initWithData:work encoding:i_encoding] autorelease]);
}

+ (const char*)strNSToC:(NSString*)i_str encoding:(NSStringEncoding)i_encoding
{
	return ([i_str cStringUsingEncoding:i_encoding]);
}

+ (NSString*)strCToNS:(char*)i_str encoding:(NSStringEncoding)i_encoding
{
	return ([NSString stringWithCString:i_str encoding:i_encoding]);
}

+ (NSString*)strToNS:(char*)i_data
{
	return ([NSString stringWithFormat:@"%s", i_data]);
}

+ (NSString*)strNumToNS:(NSInteger)i_data
{
	return ([NSString stringWithFormat:@"%d", i_data]);
}

+ (NSString*)strShortToNS:(SInt16)i_data
{
	return ([NSString stringWithFormat:@"%d", i_data]);
}

+ (NSString*)strLongToNS:(SInt32)i_data
{
	return ([NSString stringWithFormat:@"%d", i_data]);
}

+ (NSString*)strFloatToNS:(Float32)i_data
{
	return ([NSString stringWithFormat:@"%f", i_data]);
}

@end
