/**
 * @file TMMainMenu.m
 *
 * @brief Main Class.
 *
 * @author
 *  Copyright (C) SEIKO EPSON CORPORATION 2009.
 *
 *  Driver for EPSON Thermal Printers Series.
 */

#import "TMMainMenu.h"

#pragma mark -
@interface TMMainMenu (no_warnings)

-(OSStatus) TMAppPrint;
-(void) TMTerminate;

@end

#pragma mark -
@implementation TMMainMenu

#pragma mark # Override Related #
- (id)init
{
	self = [super init];
	if( self )
	{
	}
	
	return self;
}

- (void )dealloc
{
	if( iTMSDKSampleWindow != nil ) 
		[iTMSDKSampleWindow release];


	[super dealloc];
}

- (void)awakeFromNib
{ 
	
	iDataManager = [[TMDataManager alloc] initUIManager];
	iTMSDKSampleWindow = [[TMSDKSample alloc] initUIManager:iDataManager];

	[[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(TMMainWindowClosed:) name:@"TMSDKSamplePrintNotififcation" object:nil];
	
}

- (void)applicationDidFinishLaunching:(NSNotification *)aNotification
{
	
}

- (void)applicationWillTerminate:(NSNotification *)aNotification
{

}


#pragma mark # Function Related #
-(void) TMMainWindowClosed:(NSNotification*)notification
{
	if([[notification object] isEqualToString:@"OK"] == YES){

		[self TMAppPrint];
		
	}else{		
		[self TMTerminate];
	}
	
	
}

-(OSStatus) TMAppPrint
{
	OSStatus		err = noErr;

	NSPrintInfo		*printInfo = [NSPrintInfo sharedPrintInfo];
	NSString		*printerName = [iDataManager getSelectPrinterName];
	NSString		*queName = [iDataManager getSelectQueName];
	SInt16			printMode = [iDataManager getIsEmptyData];

	if( printMode == TMLibPrintNomal ) {
		NSString		*resolution = [iDataManager getDataFromKeyword:@kPDEResolutionDictKey];
		NSString		*speed = [iDataManager getDataFromKeyword:@kPDEPrintSpeedDictKey];
		NSString		*blank = [iDataManager getDataFromKeyword:@kPDEBlankLineSkipDictKey];
		NSString		*paperCut = [iDataManager getDataFromKeyword:@kPDECutTypeDictKey];
		NSString		*chashDrwr1 = [iDataManager getDataFromKeyword:@kPDECashDrawer1DictKey];
		NSString		*chashDrwr2 = [iDataManager getDataFromKeyword:@kPDECashDrawer2DictKey];
		NSString		*buzzerControl = [iDataManager getDataFromKeyword:@kPDEBuzzerControlDictKey];
		NSString		*buzzerPattern = [iDataManager getDataFromKeyword:@kPDEBuzzerPatternDictKey];
		NSString		*buzzerRepeat = [iDataManager getDataFromKeyword:@kPDEBuzzerRepeatDictKey];
		
		NSSize			paperSize = [iDataManager getPaperSize:[iDataManager getDataFromKeyword:@kMediaDictKey]];

		err = [TMPrintSupport TMSetJobTicket:printInfo
								 printerName:(NSString*)printerName
								documentSize:(NSSize)paperSize
								  resolution:resolution
									   speed:speed
									   blank:blank
									paperCut:paperCut
								  chashDrwr1:chashDrwr1
								  chashDrwr2:chashDrwr2
							   buzzerControl:buzzerControl
							   buzzerPattern:buzzerPattern
								buzzerRepeat:buzzerRepeat];
		
		if( err == noErr ) {

			NSPrintOperation *printOperation = [NSPrintOperation printOperationWithView:[iTMSDKSampleWindow getTextView] printInfo:printInfo];
			[printOperation setCanSpawnSeparateThread:YES];
			
			[printOperation setShowPanels:NO];
			[printOperation runOperation];
		}
	} else {
		err = [TMPrintSupport TMSetEmptyData:queName];
	}

	return err;
}

-(void) TMTerminate
{
	if( iTMSDKSampleWindow != nil ) 
		[iTMSDKSampleWindow release];

	[NSApp terminate:self];
}



@end
