/**
 * @file TMSDKSample.m
 *
 * @brief Sample Window Class.
 *
 * @author
 *  Copyright (C) SEIKO EPSON CORPORATION 2009.
 *
 *  Driver for EPSON Thermal Printers Series.
 */


#import "TMSDKSample.h"

#pragma mark -
@interface TMSDKSample (no_warnings)

- (NSString *)getNibName;
- (void)loadNib;
- (void)setupPopupButtonRange:(NSPopUpButton*)popup keyword:(NSString*)keyword;
- (void)setupPrinterNameList:(NSPopUpButton*)popup;
- (void)setUIValueToPopupButton:(NSPopUpButton*)popup choice:(NSString*)choice;
- (void)setupUI;

@end

#pragma mark -
@implementation TMSDKSample


#pragma mark # Action Related #
/*! Print */
- (IBAction)aPrintButton:(id)sender
{
	[[NSNotificationCenter defaultCenter] postNotification:[NSNotification notificationWithName:@"TMSDKSamplePrintNotififcation" object:@"OK"]];
}

/*! Cancel */
- (IBAction)aCancelButton:(id)sender
{
	[self closeWindow];
	[[NSNotificationCenter defaultCenter] postNotification:[NSNotification notificationWithName:@"TMSDKSamplePrintNotififcation" object:@"CANCEL"]];
}

/*! EmptyDataCheck */
- (IBAction)aEmptyDataCheck:(id)sender
{
	BOOL	flag = YES;
	
	[iDataManager setIsEmptyData:[iEmptyDataCheck state]];
	
	if( [iEmptyDataCheck state] > 0 ){
		flag = NO;
	}
	[iResolutionTitle setEnabled:flag];
	[iResolutionValue setEnabled:flag];
	[iPrintSpeedTitle setEnabled:flag];
	[iPrintSpeedValue setEnabled:flag];
	[iBlankLineSkipTitle setEnabled:flag];
	[iBlankLineSkipValue setEnabled:flag];
	[iCutTypeValue setEnabled:flag];
	[iCutTypeTitle setEnabled:flag];

	[iCashDrw1Value setEnabled:flag];
	[iCashDrw1Title setEnabled:flag];
	[iCashDrw2Value setEnabled:flag];
	[iCashDrw2Title setEnabled:flag];

	[iBuzzerControlValue setEnabled:flag];
	[iBuzzerControlTitle setEnabled:flag];
	[iBuzzerPatternValue setEnabled:flag];
	[iBuzzerPatternTitle setEnabled:flag];
	[iBuzzerRepeatValue setEnabled:flag];
	[iBuzzerRepeatTitle setEnabled:flag];
}

/*! PrinterName  */
- (IBAction)aPrinterNameValue:(id)sender
{
	NSInteger	index = [sender indexOfSelectedItem];
	
	if( [iDataManager getSelectPrinterNameIndex] != index ){
		[iDataManager setSelectPrinterNameIndex:index];
		[self setupUI];
	}
	
	[iDataManager setSelectPrinterNameIndex:[sender indexOfSelectedItem]];
	
}

/*! paperSize  */
- (IBAction)aPaperSizeValue:(id)sender
{
	[iDataManager setPopupButtonData:[sender itemTitleAtIndex:[sender indexOfSelectedItem]] keyword:@kMediaDictKey];
	NSSize			paperSize = [iDataManager getPaperSize:[iDataManager getDataFromKeyword:@kMediaDictKey]];
	[iTextView setPaperViewSize:paperSize];
	[iTextView setNeedsDisplay:YES];
}

/*! Resolution */
- (IBAction)aResolutionValue:(id)sender
{	
	[iDataManager setPopupButtonData:[sender itemTitleAtIndex:[sender indexOfSelectedItem]] keyword:@kPDEResolutionDictKey];
}

/*! PrintSpeed */
- (IBAction)aPrintSpeedValue:(id)sender
{	
	[iDataManager setPopupButtonData:[sender itemTitleAtIndex:[sender indexOfSelectedItem]] keyword:@kPDEPrintSpeedDictKey];
}

/*! BlankLineSkip */
- (IBAction)aBlankLineSkipValue:(id)sender
{	
	[iDataManager setPopupButtonData:[sender itemTitleAtIndex:[sender indexOfSelectedItem]] keyword:@kPDEBlankLineSkipDictKey];
}

/*! CutType */
- (IBAction)aCutTypeValue:(id)sender
{	
	[iDataManager setPopupButtonData:[sender itemTitleAtIndex:[sender indexOfSelectedItem]] keyword:@kPDECutTypeDictKey];
}


/*! CashDrw1 */
- (IBAction)aCashDrw1Value:(id)sender
{	
	[iDataManager setPopupButtonData:[sender itemTitleAtIndex:[sender indexOfSelectedItem]] keyword:@kPDECashDrawer1DictKey];
}

/*! CashDrw2 */
- (IBAction)aCashDrw2Value:(id)sender
{
	[iDataManager setPopupButtonData:[sender itemTitleAtIndex:[sender indexOfSelectedItem]] keyword:@kPDECashDrawer2DictKey];
}

/*! Buzzer Control */
- (IBAction)aBuzzerControlValue:(id)sender
{	
	[iDataManager setPopupButtonData:[sender itemTitleAtIndex:[sender indexOfSelectedItem]] keyword:@kPDEBuzzerControlDictKey];
}

/*! Buzzer Pattern */
- (IBAction)aBuzzerPatternValue:(id)sender
{	
	[iDataManager setPopupButtonData:[sender itemTitleAtIndex:[sender indexOfSelectedItem]] keyword:@kPDEBuzzerPatternDictKey];
}

/*! Buzzer Repeat */
- (IBAction)aBuzzerRepeatValue:(id)sender
{	
	[iDataManager setPopupButtonData:[sender itemTitleAtIndex:[sender indexOfSelectedItem]] keyword:@kPDEBuzzerRepeatDictKey];
}

#pragma mark # Override Related #

- (void )dealloc
{
	myRelease(iDataManager);
	
	[super dealloc];
}


- (void)awakeFromNib
{
	
	[self setupPrinterNameList:iPrinterNameString];
	[self setupPopupButtonRange:iPaperSizeString keyword:@"TMTicketPageSize_"];
	[self setupPopupButtonRange:iResolutionValue keyword:@"TMTicketResolution_"];
	[self setupPopupButtonRange:iPrintSpeedValue keyword:@"TMTicketPrintSpeed_"];
	[self setupPopupButtonRange:iBlankLineSkipValue keyword:@"TMTicketBlankLineSkip_"];
	[self setupPopupButtonRange:iCutTypeValue keyword:@"TMTicketCutType_"];
	[self setupPopupButtonRange:iCashDrw1Value keyword:@"TMTicketCashDrawer1_"];
	[self setupPopupButtonRange:iCashDrw2Value keyword:@"TMTicketCashDrawer2_"];
	[self setupPopupButtonRange:iBuzzerControlValue keyword:@"TMTicketBuzzerControl_"];
	[self setupPopupButtonRange:iBuzzerPatternValue keyword:@"TMTicketBuzzerPattern_"];
	[self setupPopupButtonRange:iBuzzerRepeatValue keyword:@"TMTicketBuzzerRepeat_"];
	
	[iPrinterNameString selectItemAtIndex:[iDataManager getSelectPrinterNameIndex]];
	
	[self setupUI];
	
	if( [iDataManager getSelectPrinterNameIndex] == -1 ){
		[iPrintButton setEnabled:NO];
	}
}

#pragma mark # Public Functions #

- (NSString *)getNibName 
{
    return @"TMSDKSample";
}

- (void)loadNib
{
	[NSBundle loadNibNamed:[self getNibName] owner:self];
}

- (id)initUIManager:(TMDataManager*)manager
{
	self = [super init];
	if( self )
	{
		iDataManager = [manager retain];
		[self loadNib];
	}
	
	return self;
}

- (void)closeWindow
{
	[iWindow orderOut:self];
	
}

- (void)showWindow
{

	[iWindow makeKeyAndOrderFront:self];
	
}

- (BOOL)isWindowVisible 
{
    return [iWindow isVisible];
}

- (NSView*)getTextView
{
	return iTextView;
	
}

#pragma mark # Private Functions #

- (void)setupUI
{
	NSString		*choice = nil;
	
	[iDataManager setIsEmptyData:0];
	[iEmptyDataCheck setState:[iDataManager getIsEmptyData]];
	
	choice = [iPaperSizeString itemTitleAtIndex:0];
	[iDataManager setPopupButtonData:choice keyword:@kMediaDictKey];
	[self setUIValueToPopupButton:iPaperSizeString choice:choice];
	
	choice = [iDataManager getPopupButtonDefaultData: @kPDEResolutionDictKey];
	if( choice != nil ){
		[iDataManager setPopupButtonData:choice keyword:@kPDEResolutionDictKey];
	} else {
		[iDataManager setPopupButtonData:[iResolutionValue itemTitleAtIndex:0] keyword:@kPDEResolutionDictKey];
	}
	[self setUIValueToPopupButton:iResolutionValue choice:choice];
	
	choice = [iDataManager getPopupButtonDefaultData: @kPDEPrintSpeedDictKey];
	if( choice != nil ){
		[iDataManager setPopupButtonData:choice keyword:@kPDEPrintSpeedDictKey];
	} else {
		[iDataManager setPopupButtonData:[iPrintSpeedValue itemTitleAtIndex:0] keyword:@kPDEPrintSpeedDictKey];
	}
	[self setUIValueToPopupButton:iPrintSpeedValue choice:choice];
	
	choice = [iDataManager getPopupButtonDefaultData: @kPDEBlankLineSkipDictKey];
	if( choice != nil ){
		[iDataManager setPopupButtonData:choice keyword:@kPDEBlankLineSkipDictKey];
	} else {
		[iDataManager setPopupButtonData:[iBlankLineSkipValue itemTitleAtIndex:0] keyword:@kPDEBlankLineSkipDictKey];
	}
	[self setUIValueToPopupButton:iBlankLineSkipValue choice:choice];
	
	choice = [iDataManager getPopupButtonDefaultData: @kPDECutTypeDictKey];
	if( choice != nil ){
		[iDataManager setPopupButtonData:choice keyword:@kPDECutTypeDictKey];
	} else {
		[iDataManager setPopupButtonData:[iCutTypeValue itemTitleAtIndex:0] keyword:@kPDECutTypeDictKey];
	}
	[self setUIValueToPopupButton:iCutTypeValue choice:choice];
	
	choice = [iDataManager getPopupButtonDefaultData: @kPDECashDrawer1DictKey];
	if( choice != nil ){
		[iDataManager setPopupButtonData:choice keyword:@kPDECashDrawer1DictKey];
	} else {
		[iDataManager setPopupButtonData:[iCashDrw1Value itemTitleAtIndex:0] keyword:@kPDECashDrawer1DictKey];
	}
	[self setUIValueToPopupButton:iCashDrw1Value choice:choice];
	
	choice = [iDataManager getPopupButtonDefaultData: @kPDECashDrawer2DictKey];
	if( choice != nil ){
		[iDataManager setPopupButtonData:choice keyword:@kPDECashDrawer2DictKey];
	} else {
		[iDataManager setPopupButtonData:[iCashDrw2Value itemTitleAtIndex:0] keyword:@kPDECashDrawer2DictKey];
	}
	[self setUIValueToPopupButton:iCashDrw2Value choice:choice];
	
	choice = [iDataManager getPopupButtonDefaultData: @kPDEBuzzerControlDictKey];
	if( choice != nil ){
		[iDataManager setPopupButtonData:choice keyword:@kPDEBuzzerControlDictKey];
	} else {
		[iDataManager setPopupButtonData:[iBuzzerControlValue itemTitleAtIndex:0] keyword:@kPDEBuzzerControlDictKey];
	}
	[self setUIValueToPopupButton:iBuzzerControlValue choice:choice];
	
	choice = [iDataManager getPopupButtonDefaultData: @kPDEBuzzerPatternDictKey];
	if( choice != nil ){
		[iDataManager setPopupButtonData:choice keyword:@kPDEBuzzerPatternDictKey];
	} else {
		[iDataManager setPopupButtonData:[iBuzzerPatternValue itemTitleAtIndex:0] keyword:@kPDEBuzzerPatternDictKey];
	}
	[self setUIValueToPopupButton:iBuzzerPatternValue choice:choice];
	
	choice = [iDataManager getPopupButtonDefaultData: @kPDEBuzzerRepeatDictKey];
	if( choice != nil ){
		[iDataManager setPopupButtonData:choice keyword:@kPDEBuzzerRepeatDictKey];
	} else {
		[iDataManager setPopupButtonData:[iBuzzerRepeatValue itemTitleAtIndex:0] keyword:@kPDEBuzzerRepeatDictKey];
	}
	[self setUIValueToPopupButton:iBuzzerRepeatValue choice:choice];
	
	
	BOOL		flag = YES;
	[iResolutionTitle setEnabled:flag];
	[iResolutionValue setEnabled:flag];
	[iPrintSpeedTitle setEnabled:flag];
	[iPrintSpeedValue setEnabled:flag];
	[iBlankLineSkipTitle setEnabled:flag];
	[iBlankLineSkipValue setEnabled:flag];
	[iCutTypeValue setEnabled:flag];
	[iCutTypeTitle setEnabled:flag];
	
	[iCashDrw1Value setEnabled:flag];
	[iCashDrw1Title setEnabled:flag];
	[iCashDrw2Value setEnabled:flag];
	[iCashDrw2Title setEnabled:flag];
	
	[iBuzzerControlValue setEnabled:flag];
	[iBuzzerControlTitle setEnabled:flag];
	[iBuzzerPatternValue setEnabled:flag];
	[iBuzzerPatternTitle setEnabled:flag];
	[iBuzzerRepeatValue setEnabled:flag];
	[iBuzzerRepeatTitle setEnabled:flag];
	
	if( [iDataManager getSelectPrinterNameIndex] == -1 ){
		[iPrintButton setEnabled:NO];
	}
	
	NSSize			paperSize = [iDataManager getPaperSize:[iDataManager getDataFromKeyword:@kMediaDictKey]];
	[iTextView setPaperViewSize:paperSize];
}

- (void)setupPrinterNameList:(NSPopUpButton*)popup
{
	SInt16			i = 0;
	NSString		*printerName;

	[popup removeAllItems];
	while( 1 ){
		printerName = [iDataManager getPrinterNameFromIndex:i];
		if( printerName == nil ){
			break;
		} else {
			[popup addItemWithTitle:printerName];
			i++;
		}
	}
}

- (void)setupPopupButtonRange:(NSPopUpButton*)popup keyword:(NSString*)keyword
{
	NSString		*keyValueName = nil;
	NSString		*keyValueStr = nil;
	SInt16			i = 1;
	
	[popup removeAllItems];
	while( 1 ){
		keyValueName = [NSString stringWithFormat:@"%@%d", keyword, i];
		keyValueStr = [[NSBundle mainBundle] localizedStringForKey:keyValueName value:@" " table:nil];
		if( [keyValueStr isEqualToString:@" "] == YES ){
			break;
		} else {
			[popup addItemWithTitle:keyValueStr];
			i++;
		}
	}
}


- (void)setUIValueToPopupButton:(NSPopUpButton*)popup choice:(NSString*)choice
{
	if (choice != nil)
	{
		SInt32	loop;
		for (loop = 0; loop < [popup numberOfItems]; loop++)
		{
			if ([choice isEqualToString:(NSString*)[popup itemTitleAtIndex:loop]] == YES)
			//if ([choice isEqualToString:(NSString*)[[popup itemAtIndex:loop] representedObject]] == YES)
			{
				[popup selectItemAtIndex:loop];
				break;
			}
		}
	}
}

@end
